==> react-image-annotate_ns_demo-4.0.70.tgz: package/HistorySidebarBox/index.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import HistoryIcon from "@mui/icons-material/History";
import UndoIcon from "@mui/icons-material/Undo";
import { grey } from "@mui/material/colors";
import IconButton from "@mui/material/IconButton";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemSecondaryAction from "@mui/material/ListItemSecondaryAction";
import ListItemText from "@mui/material/ListItemText";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { makeStyles } from "@mui/styles";
import isEqual from "lodash/isEqual";
import moment from "moment";
import React, { memo } from "react";
import { setIn } from "seamless-immutable";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return {
    emptyText: {
      fontSize: 14,
      fontWeight: "bold",
      color: grey[500],
      textAlign: "center",
      padding: 20
    }
  };
});
var listItemTextStyle = {
  paddingLeft: 16
};
export var HistorySidebarBox = function HistorySidebarBox(_ref) {
  var history = _ref.history,
      onRestoreHistory = _ref.onRestoreHistory,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation;
  var classes = useStyles();

  var undoAnnotation = function undoAnnotation() {
    var lastElement = window.undoArray[window.undoArray.length - 1];

    if (lastElement === "annotation") {
      onRestoreHistory();

      var newArr = _toConsumableArray(window.undoArray);

      newArr.splice(window.undoArray.length - 1, 1);
      window.undoArray = newArr;
    } else if (lastElement === "brush") {
      window.undoBrush();

      var _newArr = _toConsumableArray(window.undoArray);

      _newArr.splice(window.undoArray.length - 1, 1);

      window.undoArray = _newArr;
    }
  };

  var handleUndoKeydown = function handleUndoKeydown() {
    var _window$annotation_re, _window$annotation_re2, _window$annotation_re3, _window$annotation_re4;

    if ((_window$annotation_re = window.annotation_redo[window.annotation_redo.length - 1]) !== null && _window$annotation_re !== void 0 && (_window$annotation_re2 = _window$annotation_re.brush) !== null && _window$annotation_re2 !== void 0 && (_window$annotation_re3 = _window$annotation_re2.points) !== null && _window$annotation_re3 !== void 0 && _window$annotation_re3.length) {
      window.hendleBrush_redo();
    } else if ((_window$annotation_re4 = window.annotation_redo[window.annotation_redo.length - 1]) !== null && _window$annotation_re4 !== void 0 && _window$annotation_re4.annotation) {
      window.hendleAnnotation_redo();
    }
  };

  var handleKeydown = function handleKeydown(key) {
    var _key$target2, _key$target2$parentNo;

    if (window.undoArray.length) {
      var _key$target, _key$target$parentNod;

      if (key.ctrlKey && key.code === "KeyZ") {
        undoAnnotation();
      } else if (key.target.id === "undo" || key.target.ariaLabel === "undo annotation" || _toConsumableArray((key === null || key === void 0 ? void 0 : (_key$target = key.target) === null || _key$target === void 0 ? void 0 : (_key$target$parentNod = _key$target.parentNode) === null || _key$target$parentNod === void 0 ? void 0 : _key$target$parentNod.classList) || []).indexOf("fa-undo") !== -1) {
        undoAnnotation();
      }
    } else {
      console.log("cant undo anymore");
    }

    if (key.ctrlKey && key.code === "KeyY") {
      handleUndoKeydown();
    } else if (key.target.id === "redo" || key.target.ariaLabel === "redo annotation" || _toConsumableArray((key === null || key === void 0 ? void 0 : (_key$target2 = key.target) === null || _key$target2 === void 0 ? void 0 : (_key$target2$parentNo = _key$target2.parentNode) === null || _key$target2$parentNo === void 0 ? void 0 : _key$target2$parentNo.classList) || []).indexOf("fa-redo") !== -1) {
      handleUndoKeydown();
    }
  };

  var clearWindow = function clearWindow() {
    window.removeEventListener("keydown", handleKeydown);
    window.removeEventListener("click", handleKeydown);
  };

  React.useEffect(function () {
    window.addEventListener("click", handleKeydown);
    window.addEventListener("keydown", handleKeydown);
    return function () {
      clearWindow();
    };
  }, []);
  React.useEffect(function () {
    if (history.length > window.undoArray.filter(function (d) {
      return d === "annotation";
    }).length) {
      window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["annotation"]);
    }
  }, [history.length]);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "History",
    icon: /*#__PURE__*/React.createElement(HistoryIcon, {
      style: {
        color: grey[700]
      }
    }),
    expandedByDefault: true
  }, /*#__PURE__*/React.createElement(List, null, history.length === 0 && /*#__PURE__*/React.createElement("div", {
    className: classes.emptyText
  }, "No History Yet"), history.map(function (_ref2, i) {
    var name = _ref2.name,
        time = _ref2.time;
    return /*#__PURE__*/React.createElement(ListItem, {
      button: true,
      dense: true,
      key: i
    }, /*#__PURE__*/React.createElement(ListItemText, {
      style: listItemTextStyle,
      primary: name,
      secondary: moment(time).format("LT")
    }), i === 0 && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
      onClick: function onClick() {
        if (name === "Delete Region") {
          console.log(history);
        }

        onRestoreHistory();
      }
    }, /*#__PURE__*/React.createElement(IconButton, null, /*#__PURE__*/React.createElement(UndoIcon, null))));
  }))));
};
export default memo(HistorySidebarBox, function (prevProps, nextProps) {
  return isEqual(prevProps.history.map(function (a) {
    return [a.name, a.time];
  }), nextProps.history.map(function (a) {
    return [a.name, a.time];
  }));
});

==> react-image-annotate_ns_demo-5.0.11.tgz: package/HistorySidebarBox/index.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import HistoryIcon from "@mui/icons-material/History";
import UndoIcon from "@mui/icons-material/Undo";
import { grey } from "@mui/material/colors";
import IconButton from "@mui/material/IconButton";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemSecondaryAction from "@mui/material/ListItemSecondaryAction";
import ListItemText from "@mui/material/ListItemText";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { makeStyles } from "@mui/styles";
import isEqual from "lodash/isEqual";
import moment from "moment";
import React, { memo } from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return {
    emptyText: {
      fontSize: 14,
      fontWeight: "bold",
      color: grey[500],
      textAlign: "center",
      padding: 20
    }
  };
});
var listItemTextStyle = {
  paddingLeft: 16
};
export var HistorySidebarBox = function HistorySidebarBox(_ref) {
  var history = _ref.history,
      onRestoreHistory = _ref.onRestoreHistory,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation;
  var classes = useStyles();

  var undoAnnotation = function undoAnnotation() {
    var lastElement = window.undoArray[window.undoArray.length - 1];

    if (lastElement === "annotation") {
      onRestoreHistory();

      var newArr = _toConsumableArray(window.undoArray);

      newArr.splice(window.undoArray.length - 1, 1);
      window.undoArray = newArr;
    } else if (lastElement === "brush") {
      var _window$annotation_re, _window$annotation_re2;

      if ((_window$annotation_re = window.annotation_redo[window.annotation_redo.length - 1]) !== null && _window$annotation_re !== void 0 && (_window$annotation_re2 = _window$annotation_re.brush) !== null && _window$annotation_re2 !== void 0 && _window$annotation_re2.length) {
        window.handleBrush_delete();
      } else {
        window.undoBrush();

        var _newArr = _toConsumableArray(window.undoArray);

        _newArr.splice(window.undoArray.length - 1, 1);

        window.undoArray = _newArr;
      }
    }
  };

  var handleUndoKeydown = function handleUndoKeydown() {
    var _window$annotation_re3, _window$annotation_re4, _window$annotation_re5, _window$annotation_re6;

    if ((_window$annotation_re3 = window.annotation_redo[window.annotation_redo.length - 1]) !== null && _window$annotation_re3 !== void 0 && (_window$annotation_re4 = _window$annotation_re3.brush) !== null && _window$annotation_re4 !== void 0 && (_window$annotation_re5 = _window$annotation_re4.points) !== null && _window$annotation_re5 !== void 0 && _window$annotation_re5.length) {
      window.hendleBrush_redo();
    } else if ((_window$annotation_re6 = window.annotation_redo[window.annotation_redo.length - 1]) !== null && _window$annotation_re6 !== void 0 && _window$annotation_re6.annotation) {
      window.hendleAnnotation_redo();
    }
  };

  var handleKeydown = function handleKeydown(key) {
    var _key$target2, _key$target2$parentNo;

    if (window.undoArray.length) {
      var _key$target, _key$target$parentNod;

      if (key.ctrlKey && key.code === "KeyZ") {
        undoAnnotation();
      } else if (key.target.id === "undo" || key.target.ariaLabel === "undo annotation" || _toConsumableArray((key === null || key === void 0 ? void 0 : (_key$target = key.target) === null || _key$target === void 0 ? void 0 : (_key$target$parentNod = _key$target.parentNode) === null || _key$target$parentNod === void 0 ? void 0 : _key$target$parentNod.classList) || []).indexOf("fa-undo") !== -1) {
        undoAnnotation();
      }
    } else {
      console.log("cant undo anymore");
    }

    if (key.ctrlKey && key.code === "KeyY") {
      handleUndoKeydown();
    } else if (key.target.id === "redo" || key.target.ariaLabel === "redo annotation" || _toConsumableArray((key === null || key === void 0 ? void 0 : (_key$target2 = key.target) === null || _key$target2 === void 0 ? void 0 : (_key$target2$parentNo = _key$target2.parentNode) === null || _key$target2$parentNo === void 0 ? void 0 : _key$target2$parentNo.classList) || []).indexOf("fa-redo") !== -1) {
      handleUndoKeydown();
    }
  };

  var clearWindow = function clearWindow() {
    window.removeEventListener("keydown", handleKeydown);
    window.removeEventListener("click", handleKeydown);
  };

  React.useEffect(function () {
    window.addEventListener("click", handleKeydown);
    window.addEventListener("keydown", handleKeydown);
    return function () {
      clearWindow();
    };
  }, []);
  React.useEffect(function () {
    if (history.length > window.undoArray.filter(function (d) {
      return d === "annotation";
    }).length) {
      window.undoArray = [].concat(_toConsumableArray(window.undoArray), ["annotation"]);
    }
  }, [history.length]);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "History",
    icon: /*#__PURE__*/React.createElement(HistoryIcon, {
      style: {
        color: grey[700]
      }
    }),
    expandedByDefault: true
  }, /*#__PURE__*/React.createElement(List, null, history.length === 0 && /*#__PURE__*/React.createElement("div", {
    className: classes.emptyText
  }, "No History Yet"), history.map(function (_ref2, i) {
    var name = _ref2.name,
        time = _ref2.time;
    return /*#__PURE__*/React.createElement(ListItem, {
      button: true,
      dense: true,
      key: i
    }, /*#__PURE__*/React.createElement(ListItemText, {
      style: listItemTextStyle,
      primary: name,
      secondary: moment(time).format("LT")
    }), i === 0 && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
      onClick: function onClick() {
        if (name === "Delete Region") {
          console.log(history);
        }

        onRestoreHistory();
      }
    }, /*#__PURE__*/React.createElement(IconButton, null, /*#__PURE__*/React.createElement(UndoIcon, null))));
  }))));
};
export default memo(HistorySidebarBox, function (prevProps, nextProps) {
  return isEqual(prevProps.history.map(function (a) {
    return [a.name, a.time];
  }), nextProps.history.map(function (a) {
    return [a.name, a.time];
  }));
});
